@@ -382,7 +382,6 @@ def apply_colorbar(
     cbar_shrink=0.3,
     cmap=None,
     orientation='horizontal',
-    invisible=False,
 ):
     """
     This function applies a colorbar to the figure and formats the ticks.
@@ -442,20 +441,31 @@ def apply_colorbar(
 
         minorticks = symlog(minorticks, linthresh)
         minorticks = minorticks[(minorticks >= ticks[0]) & (minorticks <= ticks[-1])]
-        cb.ax.xaxis.set_ticks(minorticks, minor=True)
+        if orientation == 'horizontal':
+            cb.ax.xaxis.set_ticks(minorticks, minor=True)
+        elif orientation == 'vertical':
+            cb.ax.yaxis.set_ticks(minorticks, minor=True)
 
-    cb.ax.tick_params(
-        which="both",
-        axis="x",
-        direction="in",
-    )
-    cb.ax.xaxis.labelpad = 0
+    if orientation == 'horizontal':
+        cb.ax.tick_params(
+            which="both",
+            axis="x",
+            direction="in",
+        )
+        cb.ax.xaxis.labelpad = 0
+    elif orientation == 'vertical':
+        cb.ax.tick_params(
+            which="both",
+            axis="y",
+            direction="in",
+        )
+        cb.ax.yaxis.labelpad = 0
+
+        ylabels = cb.ax.get_yticklabels()
+        cb.ax.set_yticklabels(ylabels, Rotation= 90)
     # workaround for issue with viewers, see colorbar docstring
     cb.solids.set_edgecolor("face")
 
-    if invisible:
-        mpl.figure.Figure.delaxes(fig, fig.axes[1])
-
     return cb
 
 
@@ -816,7 +826,6 @@ def mask_map(m, mask):
     #m *= mask
     return m
 
-
 def create_70GHz_mask(sky_frac, nside=256, pol=False):
     """
     Creates a mask from a 70GHz frequency map at nside=256 for a 
