@@ -24,7 +24,6 @@ def plot(
     max=None,
     rng=None,
     cbar=True,
-    cbar_invisible=False,
     unit=None,
     fwhm=0.0 * u.arcmin,
     nside=None,
@@ -38,7 +37,7 @@ def plot(
     title=None,
     right_label=None,
     left_label=None,
-    width=None,
+    width=4.7,
     xsize=1000,
     darkmode=False,
     interactive=False,
@@ -63,6 +62,7 @@ def plot(
     phi_convention="counterclockwise",
     custom_xtick_labels=None,
     custom_ytick_labels=None,
+    ratio=None,
 ):
     """
     General plotting function for healpix maps.
@@ -192,9 +192,9 @@ def plot(
     custom_ytick_labels : list
         override y-axis tick labels
     """
-    
+
     # Pick sizes from size dictionary for page width plots
-    if width is None:
+    if False:
         override_plot_properties = None
     else:
         try:
@@ -202,7 +202,8 @@ def plot(
         except ValueError:
             if isinstance(width, str):
                 width = FIGURE_WIDTHS[width]
-        ratio = 0.63 if cbar else 0.5
+        if ratio is None:
+            ratio = 0.63 if cbar else 0.5
         xsize = int((1000 / 8.5) * width)
         override_plot_properties = {
             "figure_width": width,
@@ -210,10 +211,10 @@ def plot(
         }
         if cb_orientation == 'horizontal':
             override_plot_properties["cbar_pad"]    =  0.04
-            override_plot_properties["cbar_shrink"] =  0.3,
+            override_plot_properties["cbar_shrink"] =  0.3
         elif cb_orientation == 'vertical':
             override_plot_properties["cbar_pad"]    =  0.02
-            override_plot_properties["cbar_shrink"] =  0.5,
+            override_plot_properties["cbar_shrink"] =  0.8
 
     if not fontsize:
         fontsize = DEFAULT_FONTSIZES
@@ -361,6 +362,9 @@ def plot(
                 cbar_pad =  0.02
                 cbar_shrink =  0.5
 
+        # Remove color bar because of healpy bug
+        plt.gca().collections[-1].colorbar.remove()
+
         # Add pretty color bar
         if cbar:
             apply_colorbar(
@@ -376,29 +380,29 @@ def plot(
                 cbar_pad=cbar_pad,
                 cbar_shrink=cbar_shrink,
                 orientation=cb_orientation,
-                invisible=cbar_invisible
             )
 
     #### Right Title ####
     plt.text(
-        0.925,
+        0.975,
         0.925,
         params["right_label"],
-        ha="center",
+        ha="right",
         va="center",
         fontsize=fontsize["right_label"],
         transform=plt.gca().transAxes,
     )
     #### Left Title (stokes parameter label by default) ####
     plt.text(
-        0.075,
+        0.025,
         0.925,
         params["left_label"],
-        ha="center",
+        ha="left",
         va="center",
         fontsize=fontsize["left_label"],
         transform=plt.gca().transAxes,
     )
-
+    if cb_orientation == 'vertical':
+        plt.subplots_adjust(left=0.01, right=1.05)
 
     return ret, params
